==> Receipts-1.6.0.zip: __MACOSX/Receipts.app/Contents/Resources/._repair-receipts-database.sh <==
    Mac OS X            	   2  %     &*                                      ATTR      &*     %
                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements            com.apple.cs.CodeRequirements-1    X  "  com.apple.cs.CodeSignature                  4        
             Mrepair-receipts-database 8SS3YPUJH9 $\W"Ϥ´_6ze2                    MDsXa                  H    ,            com.apple.bash                     repair-receipts-database                  
*Hcd                   
*Hcd
                
subject.OU        
8SS3YPUJH9                 4        
              Mrepair-receipts-database 8SS3YPUJH9 aυpC C>(,A                                {d:"9`4ϧU*ax0	*H
010
	`He 0	*H
  ?00z!0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120201221215Z
270201221215Z0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 vO[A#+_s?5
?$?O>mG	V)甝5
ʹ`)xEii`k_#:"1O4YBx.3E
EoZ[:2m6lp&D{HX#ş9~]2_R@꾬d[jDl>İ&{^j=GX1? v(mNi&NVtKfxLY 00UW|-,T0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd 0
	*H
  B9tkƤ7*
D,Ya2Կ;P9jDt[pKl#q-_œpe-xXI(3 zvOߨJVg/>ă:wmt.#Qo`H»ZFE~' "rorPu=%] 6H9;ꐀ.`x
S>O2VMxଚBzFXV,*EK4aUD'sNp000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!0t0\Ŧ$0
	*H
 0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
170608094130Z
220609094130Z010
	&,d
8SS3YPUJH91=0;U4Developer ID Application: Dirk Holtwick (8SS3YPUJH9)10U
8SS3YPUJH910U

Dirk Holtwick10	UUS0"0
	*H
  0
 YU6>`ng4R% !|d K%j:
seSͶԧVhD;Dځ4+pf.GF,{>BR#ujAM5K?7
_4QEӕ!:~X!AXEm5t$yeP^u.D"($wˏ".G9)+g 0C28*{
:_#ivΌbV 00>+2000.+0"http://ocsp.apple.com/ocsp-devid010Uy][D+[?9Ʈ0U0 0U#0W|-,T0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U0U%0
+0
*Hcd
 0
	*H
  (3.2\_|(;5,-FM^QU&i|wL$3$TSX^Xit}piveN_ dX؋nkK5<T ֈ
BL8A-Ǭ
yFp ;N3鉬]&k\lHUSA$@ MمKsE<!/KyCf5E~R'34l[iV86ޖcϛ12ó(*u1Q0M00y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUSŦ$0
	`He 0	*H
	1	*H
0	*H
	1
171004154600Z0/	*H
	1" C؃JF	Z3*`?im0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>cdhashes</key>
	<array>
		<data>
		LL1Fhw2tKjjdOgLvPTrj2yV00cU=
		</data>
		<data>
		kniYPLpkV09RgrGGHzuJ3G/slvI=
		</data>
	</array>
</dict>
</plist>
0
	*H
  T-zZ>hM\1ZM KiimH?	ݥ7ӕOTxe:gZ^/Z!|F%q/R3*(Nh24
;=>/޿ 귶X3!nǌz N8?O	J)Ah뉕j&yvsX'C{8jUEz'd)r(\63f#(>0*H
	10	*H
010	+ 0{*H
	lj0h*010
	`He  (F6gq S(p+҇WPV;wUC3v7	20171004154600Z0	 LE%
00&Z50
	*H
 0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
170919005502Z
171031005502Z0A10UTimestamp Signer MA110U

Apple Inc.10	UUS0"0
	*H
  0
 ɖC4"nLmRӴېz$Pgr4AT{BeuKVٓ	/M0p2Z '"A  jKw֚
17HWKJƋ?b`RG#hlJٽQ=cjHm꓿;9߫H1V˯&(`wᱬODjO`is'^BI%S&KdT=. 00Uj0-0͕S#7eG0U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.03U,0*0(&$"http://crl.apple.com/timestamp.crl0U0U%0
+0
	*H
  Pͬ-#(LW	 ӣ,$0%&\"hAH0t#mJH ep'0_1mהx7o>
HiBz!bӵBN{jm!MUjDɕqshgca3Nal/ms_w
e4O^t`qm[ZڬÆ':# 2}0%bhde諚A$۞"AJl00}LWc0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120405120244Z
270405120244Z0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 wg\.#g>B	}
s@/P'4p
<No97ڞecIm] 9	:JidF5ea.
=o%L	x"!{[ѣ~I;
r3,JZr
9Pt(ny_~VVlĮ (tM&By^`EXQI^JMs{Rˣ]klt-D>a>E~4u&@u0Kw 00U4%N78X&)0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd	 0
	*H
  6qS#xe[#Ǣϴ(p!93rC=BQu]ˌjj:T}k>mzT_Cv\ N<>r4\ge0B4ӧBsu|QC`ܮ'kg3EoɘMiKEN"W""En?厸F\ɰ:m7(FeoUhR>?&:k22H;Kу000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS&Z50	+ 0	*H
	1
*H
	0	*H
	1
171004154600Z0#	*H
	1LY g9ve<0+*H
	1000]=:V=:2
C0
	*H
  G96sktdFO_$\	 -u	tOa5QTpѶ) ǴF`S;ѢjEܲR=}	<NVz?.ŹځLxְ	+$kbyB볠~-Yuշ}C
~Sfdgi>z֔>{D1wȌ]ux0i*e%BE]OЫar$&&]J͌Ϧ//      

==> Receipts-1.6.1.zip: __MACOSX/Receipts.app/Contents/Resources/._repair-receipts-database.sh <==
    Mac OS X            	   2  %     &*                                      ATTR      &*     %
                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements            com.apple.cs.CodeRequirements-1    X  "  com.apple.cs.CodeSignature                  4        
             Mrepair-receipts-database 8SS3YPUJH9 $\W"Ϥ´_6ze2                    MDsXa                  H    ,            com.apple.bash                     repair-receipts-database                  
*Hcd                   
*Hcd
                
subject.OU        
8SS3YPUJH9                 4        
              Mrepair-receipts-database 8SS3YPUJH9 aυpC C>(,A                                {d:"9`4ϧU*ax0	*H
010
	`He 0	*H
  ?00z!0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120201221215Z
270201221215Z0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 vO[A#+_s?5
?$?O>mG	V)甝5
ʹ`)xEii`k_#:"1O4YBx.3E
EoZ[:2m6lp&D{HX#ş9~]2_R@꾬d[jDl>İ&{^j=GX1? v(mNi&NVtKfxLY 00UW|-,T0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd 0
	*H
  B9tkƤ7*
D,Ya2Կ;P9jDt[pKl#q-_œpe-xXI(3 zvOߨJVg/>ă:wmt.#Qo`H»ZFE~' "rorPu=%] 6H9;ꐀ.`x
S>O2VMxଚBzFXV,*EK4aUD'sNp000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!0t0\Ŧ$0
	*H
 0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
170608094130Z
220609094130Z010
	&,d
8SS3YPUJH91=0;U4Developer ID Application: Dirk Holtwick (8SS3YPUJH9)10U
8SS3YPUJH910U

Dirk Holtwick10	UUS0"0
	*H
  0
 YU6>`ng4R% !|d K%j:
seSͶԧVhD;Dځ4+pf.GF,{>BR#ujAM5K?7
_4QEӕ!:~X!AXEm5t$yeP^u.D"($wˏ".G9)+g 0C28*{
:_#ivΌbV 00>+2000.+0"http://ocsp.apple.com/ocsp-devid010Uy][D+[?9Ʈ0U0 0U#0W|-,T0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U0U%0
+0
*Hcd
 0
	*H
  (3.2\_|(;5,-FM^QU&i|wL$3$TSX^Xit}piveN_ dX؋nkK5<T ֈ
BL8A-Ǭ
yFp ;N3鉬]&k\lHUSA$@ MمKsE<!/KyCf5E~R'34l[iV86ޖcϛ12ó(*u1Q0M00y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUSŦ$0
	`He 0	*H
	1	*H
0	*H
	1
171023152650Z0/	*H
	1" C؃JF	Z3*`?im0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>cdhashes</key>
	<array>
		<data>
		LL1Fhw2tKjjdOgLvPTrj2yV00cU=
		</data>
		<data>
		kniYPLpkV09RgrGGHzuJ3G/slvI=
		</data>
	</array>
</dict>
</plist>
0
	*H
  N^[&C9.>Z"^wS=ލB	"0j}qIbAR)ybM<}F:1::f';QVU4vr8cL-5|=DEEC<uq)7X R 
 $lE
: RFCI
yFypxϭ @(.x>s9* <T`>4}J
:pL2"5#'ҲAtky=-mQ )|0*H
	10	*H
010	+ 0z*H
	ki0g*010
	`He  QdfSq<3`CxY-w<2urdGF8B20171023152650Z0Ur
c
00OPrh0
	*H
 0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
170929182502Z
171110182502Z0B10UTimestamp Signer NWK210U

Apple Inc.10	UUS0"0
	*H
  0
 -T1<ZdsaUi6Wz{OpyCnτR+ Wי4K,RS6ԄxDZ2ISF­<'h1mAy~qGt#tC羖ҜÌn!#}/yT,|%Z
cn
ZǪ0ԉbp)KXzu
FQ;TBͳ#InD]Q8vv| H>& 00U_ꝛ&l[AxE	 0U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.03U,0*0(&$"http://crl.apple.com/timestamp.crl0U0U%0
+0
	*H
  PϞ94?m5?{n= l\YQ[͠lLc$VP/g/lC[|78sϪr"YX9
c%kt(5±:=' #ϵ`BpwL(Nze5P
tf26eˇ"PWü,Ĕ{q`9$1? <lF*LoQ{>Qcٸ#ڰDM|00}LWc0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120405120244Z
270405120244Z0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 wg\.#g>B	}
s@/P'4p
<No97ڞecIm] 9	:JidF5ea.
=o%L	x"!{[ѣ~I;
r3,JZr
9Pt(ny_~VVlĮ (tM&By^`EXQI^JMs{Rˣ]klt-D>a>E~4u&@u0Kw 00U4%N78X&)0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd	 0
	*H
  6qS#xe[#Ǣϴ(p!93rC=BQu]ˌjj:T}k>mzT_Cv\ N<>r4\ge0B4ӧBsu|QC`ܮ'kg3EoɘMiKEN"W""En?厸F\ɰ:m7(FeoUhR>?&:k22H;Kу000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUSOPrh0	+ 0	*H
	1
*H
	0	*H
	1
171023152650Z0#	*H
	1ޢaYYd}>0+*H
	1000i8
ڐ
+r=0
	*H
  }BJy2y!Kw\K,xm,,vmG=,L]|\侮U̂
w<xpIƂO7UxA;9wL!Cε}ͩsv*7?<o-d&ܯYBB!e[.W`J4B]"H%@oG$mg7	0U/:{:E7J)
޳L/VޚG'V0ljÜϚI{ԙl      
